@@ -1,5 +1,5 @@
 """functions to produce a line plot"""
-from datetime import datetime
+from datetime import datetime, timezone
 import math
 import textwrap
 import os
@@ -46,7 +46,7 @@ def _check_equally_spaced(xs):
     return len(diffs) == 1, unique_xs
 
 
-def _make_pretty_ticks(x_min, x_max, axis_is_time, xs):
+def _make_pretty_ticks(x_min, x_max, axis_is_time, xs, x_axis_tz):
 
     equally_spaced, unique_xs = _check_equally_spaced(xs)
     if axis_is_time:
@@ -56,7 +56,8 @@ def _make_pretty_ticks(x_min, x_max, axis_is_time, xs):
         else:
             x_ticks_timestamps = [x_min, x_max]
 
-        x_ticks = [datetime.fromtimestamp(_xt) for _xt in x_ticks_timestamps]
+        x_ticks = [datetime.fromtimestamp(_xt, tz=x_axis_tz)
+                   for _xt in x_ticks_timestamps]
     else:
         if len(unique_xs) <= 10 and equally_spaced:
             # if small number of x and equally spaced, just use them
@@ -79,7 +80,6 @@ def _make_pretty_ticks(x_min, x_max, axis_is_time, xs):
         else:
             # add in more ticks if available
             mean = (float(max_rounded) + float(min_rounded)) / 2.
-            thrd = (float(max_rounded) + float(min_rounded)) / 3.
             if float('{:.1e}'.format(mean)) == mean:
                 x_ticks.append(float(mean))
                 l_mean = (mean + float(min_rounded)) / 2.
@@ -88,10 +88,6 @@ def _make_pretty_ticks(x_min, x_max, axis_is_time, xs):
                     if float('{:.1e}'.format(u_mean)) == u_mean:
                         x_ticks.append(float(l_mean))
                         x_ticks.append(float(u_mean))
-            elif float('{:.1e}'.format(thrd)) == thrd:
-                if float('{:.1e}'.format(2*thrd)) == 2*thrd:
-                    x_ticks.append(float(thrd))
-                    x_ticks.append(2*float(thrd))
             x_ticks.append(float(max_rounded))
             x_ticks.sort()
 
@@ -164,7 +160,9 @@ def _tm2pretty_string(x_tick, max_t_trunc, min_t_trunc, n_ticks, isfirst):
             x_out = str(x_tick.year) + '-' + x_tick.strftime("%B")[:3]
     elif min_t_trunc == 'day':
         x_out = str(x_tick).split(' ')[0]
-    elif max_t_trunc in ('hour', 'minute', 'second', 'msecond'):
+    elif max_t_trunc in ('hour', 'minute', 'second'):
+        x_out = str(x_tick).split(' ')[1].split('+')[0]
+    elif max_t_trunc in ('msecond'):
         x_out = str(x_tick).split(' ')[1]
     elif min_t_trunc in ('hour', 'minute'):
         x_out = ':'.join(str(x_tick).split(':')[0:2])
@@ -443,11 +441,24 @@ def _make_y_axis(y_ticks, y_ticks_text, y_label, vb_width, vb_height, XBUF,
 
 
 def _make_title(title, vb_width, tick_length, CLR):
+    title_x_vb = .5*vb_width
+    title_y_vb = tick_length
     if title is None:
         title_vb = ''
+    elif '\n' in title:
+        t_list = title.split('\n')
+        title_vb = _remove_extra_whitespace(f"""\
+            <text x="{title_x_vb}" y="{title_y_vb}" fill="{CLR}"
+            text-anchor="middle" dominant-baseline="hanging"
+            font-family="sans-serif" font-size="10"> """)
+        for t_i, t_l in enumerate(t_list):
+            if t_i == 0:
+                dy = '0'
+            else:
+                dy = '1.2em'
+            title_vb += f'<tspan x="{title_x_vb}" dy="{dy}"> {t_l} </tspan>'
+        title_vb += " </text>"
     else:
-        title_x_vb = .5*vb_width
-        title_y_vb = tick_length
         title_vb = _remove_extra_whitespace(f"""\
             <text x="{title_x_vb}" y="{title_y_vb}" fill="{CLR}"
             text-anchor="middle" dominant-baseline="hanging"
@@ -507,11 +518,18 @@ def base_plot(xs, ys, yus=None, yls=None, filename='plot.svg',
         y_ticks.sort()
 
     x_axis_is_time = False
+    x_axis_tz = False
     for x_index, _x in enumerate(xs):
         try:
             _x[0] / 2
         except TypeError:
             x_axis_is_time = True
+            try:
+                x_axis_tz = _x[0].tz
+            except AttributeError:
+                x_axis_tz = timezone.utc
+                _x = [datetime(*_xi.timetuple()[:6],
+                               tzinfo=timezone.utc) for _xi in _x]
             xs[x_index] = [datetime.timestamp(_xi) for _xi in _x]
 
     all_xs = xs
@@ -539,7 +557,16 @@ def base_plot(xs, ys, yus=None, yls=None, filename='plot.svg',
     y_max = max([max(y) for y in all_ys])
 
     if x_ticks is None:
-        x_ticks = _make_pretty_ticks(x_min, x_max, x_axis_is_time, all_xs)
+        x_ticks = _make_pretty_ticks(x_min, x_max, x_axis_is_time, all_xs,
+                                     x_axis_tz)
+        if x_axis_is_time:
+            x_ticks_for_min_max = [datetime.timestamp(_xt) for _xt in x_ticks]
+            all_xs = xs + [x_ticks_for_min_max]
+        else:
+            all_xs = xs + [x_ticks]
+
+        x_min = min([min(x) for x in all_xs])
+        x_max = max([max(x) for x in all_xs])
 
     if not x_axis_is_time and x_ticks_text is None:
         x_ticks_text = [_num2pretty_string(_xt) for _xt in x_ticks]
@@ -553,7 +580,10 @@ def base_plot(xs, ys, yus=None, yls=None, filename='plot.svg',
         x_ticks = [datetime.timestamp(_xt) for _xt in x_ticks]
 
     if y_ticks is None:
-        y_ticks = _make_pretty_ticks(y_min, y_max, False, all_ys)
+        y_ticks = _make_pretty_ticks(y_min, y_max, False, all_ys, None)
+        all_ys = all_ys + [y_ticks]
+        y_min = min([min(y) for y in all_ys])
+        y_max = max([max(y) for y in all_ys])
 
     if type(labels) == str and len(ys) == 1:
         labels = [labels]  # convert to list with one string
